Learn R Programming

aroma.cn (version 1.3.3)

aroma.cn-package: Package aroma.cn

Description

Analysis of copy-number estimates obtained from various platforms.

This package should be considered to be in an alpha or beta phase. You should expect the API to be changing over time.

Arguments

Requirements

This package requires the aroma.core package.

Installation and updates

To install this package, see instructions at http://www.aroma-project.org/.

To get started

To get started, see:
  1. ...

License

The releases of this package is licensed under LGPL version 2.1 or newer.

The development code of the packages is under a private licence (where applicable) and patches sent to the author fall under the latter license, but will be, if incorporated, released under the "release" license above.

References

Please cite aroma.cn as

H. Bengtsson, P. Neuvial and T.P. SpeedTumorBoost: Normalization of allele-specific tumor copy numbers from a single pair of tumor-normal genotyping microarrays, BMC Bioinformatics, 2010

H. Bengtsson, A. Ray, P. Spellman and T.P. Speed. A single-sample method for normalizing and combining full-resolutioncopy numbers from multiple platforms, labs and analysis methods, Bioinformatics, 2009

H. Bengtsson; K. Simpson; J. Bullard; K. Hansen. aroma.affymetrix: A generic framework in R for analyzing small to very large Affymetrix data sets in bounded memory, Tech Report 745, Department of Statistics, University of California, Berkeley, February 2008

H. Bengtsson, R. Irizarry, B. Carvalho, & T.P. Speed. Estimation and assessment of raw copy numbers at the single locus level, Bioinformatics, 2008