Learn R Programming

aroma.cn (version 1.3.0)

callAllelicBalanceByBAFs.PairedPSCBS: Calls regions that are in allelic balance

Description

Calls regions that are in allelic balance from the allele B fractions (BAF).

Usage

## S3 method for class 'PairedPSCBS':
callAllelicBalanceByBAFs(fit, maxScore="auto", ..., force=FALSE, cache=FALSE, verbose=FALSE)

Arguments

fit
A PairedPSCBS fit object as returned by segmentByPairedPSCBS.
maxScore
A positive double threshold. If "auto", the threshold is estimated empirically.
...
Not used.
force
If TRUE, an already called object is skipped, otherwise not.
verbose
See Verbose.

Value

  • Returns a PairedPSCBS fit object where columns for allelic imbalance scores and p-values as well as allelic balance calls are added.

See Also

Internally, testAllelicBalanceByBAFs() is used. Note that this AB caller differs from the default one in the PSCBS package, cf. callAB.PairedPSCBS.

Examples

Run this code
if (require("PSCBS") && Sys.getenv("_R_CHECK_FULL_") != "") {

# Load example ASCN data
pathname <- system.file("data-ex/PairedPSCBS,exData,chr01.Rbin", package="PSCBS");
data <- R.utils::loadObject(pathname);

# PSCBS segmentation
fit <- segmentByPairedPSCBS(data, verbose=-10);

# Normalize
fitN <- normalizeBAFsByRegions(fit, verbose=-10);

fitN2 <- callAllelicBalanceByBAFs(fitN, verbose=-10);
print(fitN2);

} # if (require("PSCBS"))

Run the code above in your browser using DataLab