callPeaks.PeaksAndValleys: Calls the peaks in peaks-and-valley estimates
Description
Calls the peaks in peaks-and-valley estimates to a set of known state.Usage
## S3 method for class 'PeaksAndValleys':
callPeaks(fit, expected=c(-1/2, -1/4, 0, +1/4, +1/2) * pi, flavor=c("decreasing", "all"), verbose=FALSE, ...)Arguments
expected
The expected locations of the peaks to be called.
flavor
A character string specifying what flavor of the
caller to use. Flavors
If flavor == "all", each peak is called to the state with the
closest expected value.
If flavor == "decreasing", the strongest peak is called to the
state with the closest expected value, then the second strongest peak
is called analogously to one of the remaining states, and so on.