Learn R Programming

aroma.cn (version 0.5.2)

callXXorXY.numeric: Calls XX or XY from ChrX allele B fractions of a normal sample

Description

Calls XX or XY from ChrX allele B fractions of a normal sample.

Usage

## S3 method for class 'numeric':
callXXorXY(betaX, betaY=NULL, flavor=c("density"), adjust=1.5, ..., censorAt=c(-0.5, +1.5), verbose=FALSE)

Arguments

betaX
A numeric vector containing ChrX allele B fractions.
betaY
A optional numeric vector containing ChrY allele B fractions.
flavor
A character string specifying the type of algorithm used.
adjust
A postive double specifying the amount smoothing for the empirical density estimator.
...
Additional arguments passed to findPeaksAndValleys().
censorAt
A double vector of length two specifying the range for which values are considered finite. Values below (above) this range are treated as -<
verbose
A logical or a Verbose object.

Value

  • Returns a ...

Missing and non-finite values

Missing and non-finite values are dropped before trying to call XX or XY.

See Also

Internally findPeaksAndValleys() is used to identify the thresholds.