Learn R Programming

aroma.cn (version 1.3.3)

normalizePrincipalCurve.matrix: Normalizes data in K dimensions using principal curves

Description

Normalizes data in K dimensions using principal curves such that afterward the data cluster (approximately linearly) along the diagonal (in K dimensions).

Usage

## S3 method for class 'matrix':
normalizePrincipalCurve(x, ..., center=TRUE, returnFit=FALSE)

Arguments

x
An NxK matrix where the columns represent the (K >= 2) dimensions.
...
Additional arguments passed to fitPrincipalCurve used for fitting the model.
center
If TRUE, normalized data is centered such that the median signal in each dimension is at zero.
returnFit
If TRUE, the fitted principal curve parameters are returned as an attribute.

Value

encoding

latin1

References

[1] Hastie, T. and Stuetzle, W, Principal Curves, JASA, 1989.

See Also

fitPrincipalCurve and backtransformPrincipalCurve.