Learn R Programming

aroma.cn (version 1.3.3)

testAllelicBalanceByBAFs: Tests for allelic balance in a genomic region

Description

Tests for allelic balance in a genomic region.

Usage

## S3 method for class 'default':
testAllelicBalanceByBAFs(betaT, muN, flavor=c("var", "mean"), ..., verbose=FALSE)

Arguments

betaT
A numeric vector of J tumor allele B fractions (BAFs).
muN
A numeric vector of J normal (germline) genotypes.
flavor
A character specifying the type of test to be performed.
...
Not used.
verbose
See Verbose.

Value

  • A list of class "htest".

Examples

Run this code
if (Sys.getenv("_R_CHECK_FULL_") != "" && require("PSCBS")) {

# Load example ASCN data
data <- PSCBS::exampleData("paired.chr01");

# PSCBS segmentation
fit <- segmentByPairedPSCBS(data, verbose=-10);

# Normalize
fitN <- normalizeBAFsByRegions(fit, verbose=-10);

fitN2 <- callAllelicBalanceByBAFs(fitN, verbose=-10);
print(fitN2);

} # if (require("PSCBS"))

Run the code above in your browser using DataLab