Requirements
This package requires the aroma.core package.Installation and updates
To install this package, see instructions at
http://www.aroma-project.org/.To get started
To get started, see:
- ...
License
The releases of this package is licensed under
LGPL version 2.1 or newer.
The development code of the packages is under a private licence
(where applicable) and patches sent to the author fall under the
latter license, but will be, if incorporated, released under the
"release" license above.