Learn R Programming

aroma.cn (version 1.3.0)

callCopyNeutralRegions.PairedPSCBS: Calls regions that are copy neutral

Description

Calls regions that are copy neutral from the allele B fractions (BAF).

Usage

## S3 method for class 'PairedPSCBS':
callCopyNeutralRegions(fit, ...)

Arguments

fit
A PairedPSCBS fit object as returned by segmentByPairedPSCBS.
...
Additional arguments passed to findNeutralCopyNumberState and callCopyNeutral.PairedPSCBS.

Value

  • Returns a PairedPSCBS fit object where a column with the copy-neutral call.

Examples

Run this code
if (require("PSCBS") && Sys.getenv("_R_CHECK_FULL_") != "") {

# Load example ASCN data
pathname <- system.file("data-ex/PairedPSCBS,exData,chr01.Rbin", package="PSCBS");
data <- R.utils::loadObject(pathname);

# PSCBS segmentation
fit <- segmentByPairedPSCBS(data, verbose=-10);

fit <- bootstrapTCNandDHByRegion(fit, verbose=-10);

fitC <- callCopyNeutralRegions(fit, verbose=-10);
print(fitC);

# Normalize
fitN <- normalizeBAFsByRegions(fitC, verbose=-10);

} # if (require("PSCBS"))

Run the code above in your browser using DataLab