Learn R Programming

aroma.cn (version 0.7.3)

callCopyNeutralRegions.PairedPSCBS: Calls regions that are copy neutral

Description

Calls regions that are copy neutral from the allele B fractions (BAF).

Usage

## S3 method for class 'PairedPSCBS':
callCopyNeutralRegions(fit, ..., force=FALSE, verbose=FALSE)

Arguments

fit
A PairedPSCBS fit object as returned by segmentByPairedPSCBS.
...
Additional arguments passed to findNeutralCopyNumberState.
force
If TRUE, an already called object is skipped, otherwise not.
verbose
See Verbose.

Value

  • Returns a PairedPSCBS fit object where a column with the copy-neutral call.

Examples

Run this code
if (require("psCBS")) {

# Load example ASCN data
pathname <- system.file("data-ex/pcCBS,exData,chr01.Rbin", package="psCBS");
data <- R.utils::loadObject(pathname);
R.oo::attachLocally(data);
x <- position;

# PSCBS segmentation
fit <- segmentByPairedPSCBS(CT, betaT=betaT, betaN=betaN, x=x, verbose=-10);

# Normalize
fitN <- normalizeBAFsByRegions(fit, verbose=-10);

fitN2 <- callCopyNeutralRegions(fitN, verbose=-10);
print(fitN2);

} # if (require("psCBS"))

Run the code above in your browser using DataLab