callXXorXY.numeric: Calls XX or XY from ChrX allele B fractions of a normal sample
Description
Calls XX or XY from ChrX allele B fractions of a normal sample.Usage
## S3 method for class 'numeric':
callXXorXY(betaX, betaY=NULL, flavor=c("density"), adjust=1.5, ..., censorAt=c(-0.5, +1.5), verbose=FALSE)Arguments
flavor
A character string specifying the type of algorithm used. adjust
A postive double specifying the amount smoothing for
the empirical density estimator. censorAt
A double vector of length two specifying the range
for which values are considered finite. Values below (above) this
range are treated as -< Missing and non-finite values
Missing and non-finite values are dropped before trying to call XX or XY.