Learn R Programming

aroma.cn (version 1.3.0)

normalizePrincipalCurve.matrix: Fit a principal curve in K dimensions

Description

Fit a principal curve in K dimensions.

Usage

## S3 method for class 'matrix':
normalizePrincipalCurve(x, ..., center=TRUE, returnFit=FALSE)

Arguments

x
An NxK matrix (K>=2) where the columns represent the dimension.
...
Additional arguments passed to fitPrincipalCurve used for fitting the model.
center
If TRUE, normalized data is centered such that the median signal in each dimension is at zero.
returnFit
If TRUE, the fitted principal curve parameters are returned as an attribute.

Value

encoding

latin1

References

[1] Hastie, T. and Stuetzle, W, Principal Curves, JASA, 1989.

See Also

fitPrincipalCurve and backtransformPrincipalCurve.