Learn R Programming

aroma.cn (version 0.8.2)

testAllelicBalanceByBAFs: Tests for allelic balance in a genomic region

Description

Tests for allelic balance in a genomic region.

Usage

## S3 method for class 'default':
testAllelicBalanceByBAFs(betaT, muN, flavor=c("var", "mean"), ..., verbose=FALSE)

Arguments

betaT
A numeric vector of J tumor allele B fractions (BAFs).
muN
A numeric vector of J normal (germline) genotypes.
flavor
A character specifying the type of test to be performed.
...
Not used.
verbose
See Verbose.

Value

  • A list of class "htest".

Examples

Run this code
if (require("PSCBS")) {

# Load example ASCN data
pathname <- system.file("data-ex/PairedPSCBS,exData,chr01.Rbin", package="PSCBS");
data <- R.utils::loadObject(pathname);
R.oo::attachLocally(data);
x <- position;

# PSCBS segmentation
fit <- segmentByPairedPSCBS(CT, betaT=betaT, betaN=betaN, x=x, verbose=-10);

# Normalize
fitN <- normalizeBAFsByRegions(fit, verbose=-10);

fitN2 <- callAllelicBalanceByBAFs(fitN, verbose=-10);
print(fitN2);

} # if (require("PSCBS"))

Run the code above in your browser using DataLab